@@ -154,6 +154,7 @@ class App(tk.Frame):
     def rightKey(self,event):
         self.menubar.delete(0, 'end')
         self.menubar.add_command(label='复制',command=lambda:self.fuzhi())
+        self.menubar.add_command(label='剪切',command=lambda:self.剪切())
         self.menubar.add_command(label='粘贴',command=lambda:self.zhantiai())
         self.menubar.add_command(label='粘贴文件名',command=lambda:self.zhantiai(wjm=True))
         self.menubar.add_command(label='导入文件',command=lambda :self.path_uis(pd="2"))
@@ -170,6 +171,9 @@ class App(tk.Frame):
         self.menubar.add_command(label='保存',command=lambda:self.dakai(pd="3",texts=app.smdq_1.get(1.0, "end").strip()))
         self.menubar.add_command(label='运行内容py',command=lambda:self.dakai(pd="4",texts=app.smdq_1.get(1.0, "end").strip()))
         self.menubar.post(event.x_root,event.y_root)    
+    def 剪切(self):
+        self.fuzhi()
+        self.bghs_删除(dx=True)
     def fuzhi(self):
         xx=[self.tree.set(x) for x in self.tree.selection()] #[{}]
         zlh=""  
